==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Swiadczenie.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.JednostkaMiary;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Swiadczenie extends GenericDPSObject {
    /**
     * SWIADCZENIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * SWIADCZENIE.GRUPA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long grupaId;

    /**
     * SWIADCZENIE.ROZLICZAJ_W_RAMACH_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rozliczajWRamachId;

    /**
     * SWIADCZENIE.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * SWIADCZENIE.JEDNOSTKA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private JednostkaMiary jednostka;

    /**
     * SWIADCZENIE.KOLEJNOSC_WYDRUK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer kolejnoscWydruk;

    /**
     * SWIADCZENIE.SKROT_WYDRUK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String skrotWydruk;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE.GRUPA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getGrupaId() {
        return grupaId;
    }

    /**
     * SWIADCZENIE.GRUPA_ID
     *
     * @param grupaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGrupaId(Long grupaId) {
        this.grupaId = grupaId;
    }

    /**
     * @return SWIADCZENIE.ROZLICZAJ_W_RAMACH_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRozliczajWRamachId() {
        return rozliczajWRamachId;
    }

    /**
     * SWIADCZENIE.ROZLICZAJ_W_RAMACH_ID
     *
     * @param rozliczajWRamachId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRozliczajWRamachId(Long rozliczajWRamachId) {
        this.rozliczajWRamachId = rozliczajWRamachId;
    }

    /**
     * @return SWIADCZENIE.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SWIADCZENIE.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return SWIADCZENIE.JEDNOSTKA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public JednostkaMiary getJednostka() {
        return jednostka;
    }

    /**
     * SWIADCZENIE.JEDNOSTKA
     *
     * @param jednostka
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setJednostka(JednostkaMiary jednostka) {
        this.jednostka = jednostka;
    }

    /**
     * @return SWIADCZENIE.KOLEJNOSC_WYDRUK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getKolejnoscWydruk() {
        return kolejnoscWydruk;
    }

    /**
     * SWIADCZENIE.KOLEJNOSC_WYDRUK
     *
     * @param kolejnoscWydruk
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKolejnoscWydruk(Integer kolejnoscWydruk) {
        this.kolejnoscWydruk = kolejnoscWydruk;
    }

    /**
     * @return SWIADCZENIE.SKROT_WYDRUK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getSkrotWydruk() {
        return skrotWydruk;
    }

    /**
     * SWIADCZENIE.SKROT_WYDRUK
     *
     * @param skrotWydruk
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkrotWydruk(String skrotWydruk) {
        this.skrotWydruk = skrotWydruk == null ? null : skrotWydruk.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Swiadczenie other = (Swiadczenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getGrupaId() == null ? other.getGrupaId() == null : this.getGrupaId().equals(other.getGrupaId()))
            && (this.getRozliczajWRamachId() == null ? other.getRozliczajWRamachId() == null : this.getRozliczajWRamachId().equals(other.getRozliczajWRamachId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getJednostka() == null ? other.getJednostka() == null : this.getJednostka().equals(other.getJednostka()))
            && (this.getKolejnoscWydruk() == null ? other.getKolejnoscWydruk() == null : this.getKolejnoscWydruk().equals(other.getKolejnoscWydruk()))
            && (this.getSkrotWydruk() == null ? other.getSkrotWydruk() == null : this.getSkrotWydruk().equals(other.getSkrotWydruk()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getGrupaId() == null) ? 0 : getGrupaId().hashCode());
        result = prime * result + ((getRozliczajWRamachId() == null) ? 0 : getRozliczajWRamachId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getJednostka() == null) ? 0 : getJednostka().hashCode());
        result = prime * result + ((getKolejnoscWydruk() == null) ? 0 : getKolejnoscWydruk().hashCode());
        result = prime * result + ((getSkrotWydruk() == null) ? 0 : getSkrotWydruk().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", grupaId=").append(grupaId);
        sb.append(", rozliczajWRamachId=").append(rozliczajWRamachId);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", jednostka=").append(jednostka);
        sb.append(", kolejnoscWydruk=").append(kolejnoscWydruk);
        sb.append(", skrotWydruk=").append(skrotWydruk);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Swiadczenie.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.JednostkaMiary;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Swiadczenie extends GenericDPSObject {
    /**
     * SWIADCZENIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * SWIADCZENIE.GRUPA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long grupaId;

    /**
     * SWIADCZENIE.ROZLICZAJ_W_RAMACH_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rozliczajWRamachId;

    /**
     * SWIADCZENIE.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * SWIADCZENIE.JEDNOSTKA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private JednostkaMiary jednostka;

    /**
     * SWIADCZENIE.KOLEJNOSC_WYDRUK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer kolejnoscWydruk;

    /**
     * SWIADCZENIE.SKROT_WYDRUK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String skrotWydruk;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return SWIADCZENIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * SWIADCZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return SWIADCZENIE.GRUPA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getGrupaId() {
        return grupaId;
    }

    /**
     * SWIADCZENIE.GRUPA_ID
     *
     * @param grupaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGrupaId(Long grupaId) {
        this.grupaId = grupaId;
    }

    /**
     * @return SWIADCZENIE.ROZLICZAJ_W_RAMACH_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRozliczajWRamachId() {
        return rozliczajWRamachId;
    }

    /**
     * SWIADCZENIE.ROZLICZAJ_W_RAMACH_ID
     *
     * @param rozliczajWRamachId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRozliczajWRamachId(Long rozliczajWRamachId) {
        this.rozliczajWRamachId = rozliczajWRamachId;
    }

    /**
     * @return SWIADCZENIE.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * SWIADCZENIE.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return SWIADCZENIE.JEDNOSTKA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public JednostkaMiary getJednostka() {
        return jednostka;
    }

    /**
     * SWIADCZENIE.JEDNOSTKA
     *
     * @param jednostka
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setJednostka(JednostkaMiary jednostka) {
        this.jednostka = jednostka;
    }

    /**
     * @return SWIADCZENIE.KOLEJNOSC_WYDRUK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getKolejnoscWydruk() {
        return kolejnoscWydruk;
    }

    /**
     * SWIADCZENIE.KOLEJNOSC_WYDRUK
     *
     * @param kolejnoscWydruk
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKolejnoscWydruk(Integer kolejnoscWydruk) {
        this.kolejnoscWydruk = kolejnoscWydruk;
    }

    /**
     * @return SWIADCZENIE.SKROT_WYDRUK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getSkrotWydruk() {
        return skrotWydruk;
    }

    /**
     * SWIADCZENIE.SKROT_WYDRUK
     *
     * @param skrotWydruk
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkrotWydruk(String skrotWydruk) {
        this.skrotWydruk = skrotWydruk == null ? null : skrotWydruk.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Swiadczenie other = (Swiadczenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getGrupaId() == null ? other.getGrupaId() == null : this.getGrupaId().equals(other.getGrupaId()))
            && (this.getRozliczajWRamachId() == null ? other.getRozliczajWRamachId() == null : this.getRozliczajWRamachId().equals(other.getRozliczajWRamachId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getJednostka() == null ? other.getJednostka() == null : this.getJednostka().equals(other.getJednostka()))
            && (this.getKolejnoscWydruk() == null ? other.getKolejnoscWydruk() == null : this.getKolejnoscWydruk().equals(other.getKolejnoscWydruk()))
            && (this.getSkrotWydruk() == null ? other.getSkrotWydruk() == null : this.getSkrotWydruk().equals(other.getSkrotWydruk()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getGrupaId() == null) ? 0 : getGrupaId().hashCode());
        result = prime * result + ((getRozliczajWRamachId() == null) ? 0 : getRozliczajWRamachId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getJednostka() == null) ? 0 : getJednostka().hashCode());
        result = prime * result + ((getKolejnoscWydruk() == null) ? 0 : getKolejnoscWydruk().hashCode());
        result = prime * result + ((getSkrotWydruk() == null) ? 0 : getSkrotWydruk().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", grupaId=").append(grupaId);
        sb.append(", rozliczajWRamachId=").append(rozliczajWRamachId);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", jednostka=").append(jednostka);
        sb.append(", kolejnoscWydruk=").append(kolejnoscWydruk);
        sb.append(", skrotWydruk=").append(skrotWydruk);
        sb.append("]");
        return sb.toString();
    }
}
